@@ -82,7 +82,7 @@ class Updater():
             self.runningVersion = runningVersion
 
         # self.headers = {'User-Agent': psychopy.constants.PSYCHOPY_USERAGENT}
-        self.latest = None
+        self.latest = getLatestVersionInfo()
         if web.proxies is None:
             web.setupProxy()
 
@@ -272,10 +272,12 @@ class InstallUpdateDialog(wx.Dialog):
             self.latest = app.updater.latest
         self.runningVersion = app.updater.runningVersion
         wx.Dialog.__init__(self, parent, ID,
-                           title=_translate('PsychoPy Updates'),
-                           size=(100, 200))
+                           title=_translate('PsychoPy Updates'))
 
+        borderSizer = wx.BoxSizer(wx.VERTICAL)
         mainSizer = wx.BoxSizer(wx.VERTICAL)
+        self.SetSizer(borderSizer)
+        borderSizer.Add(mainSizer, border=12, proportion=1, flag=wx.ALL | wx.EXPAND)
         # set the actual content of status msg later in self.updateStatus()
         self.statusMessage = wx.StaticText(
             self, -1, "msg", style=wx.ALIGN_CENTER)
@@ -285,7 +287,7 @@ class InstallUpdateDialog(wx.Dialog):
         self.useLatestBtn = wx.RadioButton(self, -1, msg,
                                            style=wx.RB_GROUP)
         self.Bind(wx.EVT_RADIOBUTTON, self.onRadioSelect, self.useLatestBtn)
-        self.progressBar = wx.Gauge(self, -1, 100, size=(250, 25))
+        self.progressBar = wx.Gauge(self, -1, 100, size=(250, 36))
         mainSizer.Add(self.useLatestBtn,
                       flag=wx.ALIGN_LEFT | wx.ALL, border=5)
         mainSizer.Add(self.progressBar, flag=wx.EXPAND | wx.ALL, border=5)
@@ -295,11 +297,10 @@ class InstallUpdateDialog(wx.Dialog):
         self.useZipBtn = wx.RadioButton(self, -1, msg)
         self.Bind(wx.EVT_RADIOBUTTON, self.onRadioSelect, self.useZipBtn)
         self.fileBrowseCtrl = wx.lib.filebrowsebutton.FileBrowseButton(
-            self, -1, size=(450, -1), changeCallback=self.onFileBrowse,
+            self, -1, size=(450, 48), changeCallback=self.onFileBrowse,
             fileMask='*.zip')
         mainSizer.Add(self.useZipBtn, flag=wx.ALIGN_LEFT | wx.ALL, border=5)
-        mainSizer.Add(self.fileBrowseCtrl,
-                      flag=wx.ALIGN_LEFT | wx.ALL, border=5)
+        mainSizer.Add(self.fileBrowseCtrl, flag=wx.ALIGN_LEFT | wx.ALL, border=5)
         # ctrls for buttons (install/cancel)
         self.installBtn = wx.Button(self, -1, _translate('Install'))
         self.Bind(wx.EVT_BUTTON, self.onInstall, self.installBtn)
@@ -314,10 +315,11 @@ class InstallUpdateDialog(wx.Dialog):
             btns = [self.cancelBtn, self.installBtn]
         btnSizer.Add(btns[0], 0, flag=wx.LEFT, border=5)
         btnSizer.Add(btns[1], 0, flag=wx.LEFT, border=5)
+        mainSizer.AddStretchSpacer()
         mainSizer.Add(btnSizer, flag=wx.ALL | wx.EXPAND, border=5)
 
-        self.SetSizerAndFit(mainSizer)
-        self.SetAutoLayout(True)
+        self.Layout()
+        self.Fit()
 
         # positioning and sizing
         self.updateStatus()
@@ -370,6 +372,7 @@ class InstallUpdateDialog(wx.Dialog):
         else:
             self.currentSelection = self.useLatestBtn
             self.useLatestBtn.SetValue(True)
+        self.Layout()
         self.Fit()
         # this will enable/disable additional controls for the above:
         self.onRadioSelect()
@@ -628,7 +631,7 @@ def sendUsageStats():
         systemInfo = "win32_v" + platform.version()
     else:
         systemInfo = platform.system() + platform.release()
-    u = "https://www.psychopy.org/usage.php?date=%s&sys=%s&version=%s&misc=%s"
+    u = "https://usage.psychopy.org/submit.php?date=%s&sys=%s&version=%s&misc=%s"
     URL = u % (dateNow, systemInfo, v, miscInfo)
     try:
         req = urllib.request.Request(URL)
